@@ -9,13 +9,14 @@ use tokio::sync::mpsc;
 use webrtc::api::interceptor_registry::register_default_interceptors;
 use webrtc::api::media_engine::MediaEngine;
 use webrtc::api::APIBuilder;
-use webrtc::data::data_channel::data_channel_message::DataChannelMessage;
+pub use webrtc::data::data_channel::data_channel_init::RTCDataChannelInit;
+pub use webrtc::data::data_channel::data_channel_message::DataChannelMessage;
 pub use webrtc::data::data_channel::data_channel_state::RTCDataChannelState;
 pub use webrtc::data::data_channel::RTCDataChannel;
 use webrtc::peer::configuration::RTCConfiguration;
 use webrtc::peer::ice::ice_server::RTCIceServer;
 use webrtc::peer::peer_connection::RTCPeerConnection;
-use webrtc::peer::peer_connection_state::RTCPeerConnectionState;
+pub use webrtc::peer::peer_connection_state::RTCPeerConnectionState;
 use webrtc::peer::sdp::session_description::RTCSessionDescription;
 
 pub struct Configuration {
@@ -243,6 +244,21 @@ impl Cyberdeck {
         }
     }
 
+    pub async fn create_channel_with_configuration(
+        &mut self,
+        name: &str,
+        config: RTCDataChannelInit,
+    ) -> Result<(), webrtc::Error> {
+        match self
+            .peer_connection
+            .create_data_channel(name, Some(config))
+            .await
+        {
+            Ok(_) => Ok(()),
+            Err(e) => Err(e),
+        }
+    }
+
     pub async fn close(&mut self) -> Result<(), webrtc::Error> {
         self.abort.send(())?;
         self.peer_connection.close().await
